summaryrefslogtreecommitdiff
path: root/macros/luatex/generic/luatexja/tool/ltj-unicode-ccfix_make2.pl
diff options
context:
space:
mode:
Diffstat (limited to 'macros/luatex/generic/luatexja/tool/ltj-unicode-ccfix_make2.pl')
-rwxr-xr-xmacros/luatex/generic/luatexja/tool/ltj-unicode-ccfix_make2.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/macros/luatex/generic/luatexja/tool/ltj-unicode-ccfix_make2.pl b/macros/luatex/generic/luatexja/tool/ltj-unicode-ccfix_make2.pl
index f55962956d..9372d2a9ab 100755
--- a/macros/luatex/generic/luatexja/tool/ltj-unicode-ccfix_make2.pl
+++ b/macros/luatex/generic/luatexja/tool/ltj-unicode-ccfix_make2.pl
@@ -1,6 +1,6 @@
#!/usr/bin/env perl
# create ltj-unicode-ccfix.tex by processing Unicode data file
# LineBreak.txt
# modified from unicode-char-prep.pl (part of the XeTeX typesetting system).
@@ -38,7 +38,7 @@
# authorization from the copyright holders.
# \****************************************************************************/
-die "usage: perl $0 LineBreak.txt > unicode-letters.tex\n"
+die "usage: perl $0 LineBreak.txt > ltj-unicode-ccfix.lua\n"
unless $#ARGV == 0;
sub parse_unidata {
@@ -1,6 +1,6 @@
#!/usr/bin/env perl
-# create ltj-unicode-ccfix.tex by processing Unicode data file
+# create ltj-unicode-ccfix.lua by processing Unicode data file
# LineBreak.txt
# modified from unicode-char-prep.pl (part of the XeTeX typesetting system).